﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;

namespace HeuristicLab.Problems.DataAnalysis.Symbolic.Views {
  [View("ParsedConstraint View")]
  [Content(typeof(ParsedConstraint), true)]
  public partial class ParsedConstraintView : AsynchronousContentView {

    public new ParsedConstraint Content {
      get => (ParsedConstraint)base.Content;
      set => base.Content = value;
    }
    public ParsedConstraintView() {
      InitializeComponent();
      constraintsOutput.ReadOnly = true;
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) {
        constraintsInput.Text = string.Empty;
        constraintsOutput.Text = string.Empty;
      } else { 
        constraintsInput.Text = Content.Input;
        constraintsOutput.Text = ConstraintsOutput(Content.Constraints ?? new List<IntervalConstraint>());
      }
    }

    private IEnumerable<IntervalConstraint> ParseConstraints(string input) {
      var parsedIntervals = IntervalConstraintsParser.Parse(input);
      return parsedIntervals;
    }

    private string ConstraintsOutput(IEnumerable<IntervalConstraint> constraints) {
      var result = "";
      var count = 1;
      foreach (var constraint in constraints) {
        result += "Constraint #" + count + ": " + Environment.NewLine;
        result += constraint.Expression + Environment.NewLine + Environment.NewLine;
        count++;
      }

      return result;
    }

    private void parseBtn_Click(object sender, EventArgs e) {
      if (constraintsInput.Text != null) {
        var constraints = ParseConstraints(constraintsInput.Text);
        constraintsOutput.Text = ConstraintsOutput(constraints);
        Content.Constraints = constraints;
        Content.Input = constraintsInput.Text;
      } else { 
        constraintsOutput.Text = "No Constraints found!";
      }
    }
  }
}
